@@ -13,7 +13,7 @@ Readonly::Hash my %LANG => (
 	'title' => 'Page title',
 );
 
-our $VERSION = 0.10;
+our $VERSION = 0.11;
 
 # Constructor.
 sub new {
@@ -145,7 +145,12 @@ sub process {
 
 	my $css;
 	if ($self->{'css'}) {
-		$css = $self->{'css'}->flush(1)."\n";
+		$css = $self->{'css'}->flush(1);
+		if ($css ne '') {
+			$css .= "\n";
+		} else {
+			undef $css;
+		}
 	}
 
 	# Begin of page.
@@ -228,7 +233,7 @@ sub process {
 		['e', 'title'],
 
 		(
-			$css ? (
+			defined $css ? (
 				['b', 'style'],
 				['a', 'type', 'text/css'],
 				['d', $css],
@@ -622,6 +627,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.10
+0.11
 
 =cut
